#!/bin/sh
# Unload wifi modules
rmmod wl1251_spi 2>/dev/null
rmmod wl1251 2>/dev/null
rmmod wl12xx 2>/dev/null
rmmod mac80211 2>/dev/null
rmmod cfg80211 2>/dev/null
rmmod rfkill_backport 2>/dev/null
rmmod compat_firmware_class 2>/dev/null
rmmod compat 2>/dev/null
# Load bleeding-edge wl1251
insmod compat.ko
insmod rfkill_backport.ko
insmod cfg80211.ko
insmod mac80211.ko
insmod wl1251.ko
insmod wl1251_spi.ko
# Restart wlancond
#stop wlancond
#start wlancond
# Start up wlan0 interface
#ifconfig wlan0 up
#ifconfig wlan0 up; sh -c "airmon-ng start wlan0 >> /dev/null &" &
